Stan Math Library: stan/math/fwd/mat/fun/typedefs.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Typedefs
typedefs.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/fwd/mat/fun/Eigen_NumTraits.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Typedefs
typedef Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index | stan::math::size_type
| Type for sizes and indexes in an Eigen matrix with double e. More...
typedef Eigen::Matrix< fvar< double >, Eigen::Dynamic, Eigen::Dynamic > | stan::math::matrix_fd
typedef Eigen::Matrix< fvar< fvar< double > >, Eigen::Dynamic, Eigen::Dynamic > | stan::math::matrix_ffd
typedef Eigen::Matrix< fvar< double >, Eigen::Dynamic, 1 > | stan::math::vector_fd
typedef Eigen::Matrix< fvar< fvar< double > >, Eigen::Dynamic, 1 > | stan::math::vector_ffd
typedef Eigen::Matrix< fvar< double >, 1, Eigen::Dynamic > | stan::math::row_vector_fd
typedef Eigen::Matrix< fvar< fvar< double > >, 1, Eigen::Dynamic > | stan::math::row_vector_ffd

[ Stan Home Page ] © 2011–2016, Stan Development Team.